{% extends "xadmin/widgets/base.html" %}
{% load i18n xadmin_tags %}

{% block content %}
  <div class="row">
    {% for btn in btns %}
    <div class="col-xs-6 col-sm-4 col-md-3">
    <a href="{{ btn.url }}" class="btn btn-primary btn-quick">
      <i class="{% if btn.icon %}{{btn.icon}}{%else%}fa fa-rocket{% endif %}"></i>
      <p>{{ btn.title }}</p>
    </a>
    </div>
    {% endfor %}
  </div>
{% endblock content %}
