{% load i18n %}
<div class="btn-group grid-layout">
  <a class="dropdown-toggle btn btn-default btn-sm" data-toggle="dropdown" href="#">
    <i class="{{current_icon}}"></i> {% trans "Layout" %} <span class="caret"></span>
  </a>
  <ul class="dropdown-menu" role="menu" aria-labelledby="dLabel">
    {% for r in layouts %}
      <li{% if r.selected %} class="active"{% endif %}>
      <a href="{{r.url}}"><i class="{{r.icon}}"></i> {{r.name}}</a></li>
    {% endfor %}
  </ul>
</div>