import xadmin
from xadmin.models import UserSettings
from xadmin.layout import *


class UserSettingsAdmin(object):
    model_icon = 'fa fa-cog'
    hidden_menu = True
xadmin.site.register(UserSettings, UserSettingsAdmin)
