.nav-quickfilter .filter-item {
	white-space: nowrap;
	overflow: hidden;
	padding: 5px;
}

.nav-quickfilter .filter-col-1 {
	margin: 3px 2px 0 -2px;
	float: left;
}

.nav-quickfilter .filter-col-2 {
}

.nav-quickfilter .nav-expand {
	z-index:100;
}