<div class="panel panel-default {% block box_class %}{% endblock box_class %}" {% block box_attrs %}{% endblock box_attrs %}>
  <div class="panel-heading"><i class='icon fa fa-chevron-up chevron'></i><h3 class="panel-title">{% block box_title %}{% endblock box_title %}</h3></div>
  <div class="panel-body {% block box_content_class %}{% endblock box_content_class %}" {% block box_content_attrs %}{% endblock box_content_attrs %}>
    {% block box_content %}{% endblock box_content %}
  </div>
  {% block box_extra %}{% endblock box_extra %}
</div>
