{% load i18n %}
<div class="selector select-transfer">
    <div class="selector-available">
        <p class="title">{% trans "Available" %} {{verbose_name}}</p>
        <div class="input-group input-group-sm selector-filter">
          <span class="input-group-addon"><i class="fa fa-search"></i></span>
          <input class="form-control" type="text" id="{{field_id}}_input">
        </div>
        <select multiple="multiple" id="{{field_id}}_form">
            {{available_options|safe}}
        </select>
        <a class="btn btn-default selector-chooseall" title="{% trans "Click to choose all at once." %}">{% trans "Choose all" %}</a>
    </div>
    <ul class="selector-chooser">
        <li>
            <a class="btn btn-default btn-sm selector-add" title="{% trans "Choose" %}"><i class="fa fa-plus"></i></a>
        </li>
        <li>
            <a class="btn btn-default btn-sm selector-remove" title="{% trans "Remove" %}"><i class="fa fa-minus"></i></a>
        </li>
    </ul>
    <div class="selector-chosen">
        <p class="title">{% trans "Chosen" %} {{verbose_name}}</p>
        <select multiple="multiple" {{flatatts|safe}}>
            {{chosen_options|safe}}
        </select>
        <a class="btn btn-default selector-clearall" title="{% trans "Click to remove all chosen at once." %}">{% trans "Remove all" %}</a>
    </div>
</div>
<div class="clearfix"></div>