{% extends base_template %}
{% load i18n xadmin_tags %}
{% load url from future %}
{% load crispy_forms_tags %}

{% block body %}
<div class="container">

  <div class="panel panel-default panel-single" style="max-width: 500px;">
    <div class="panel-heading">
      <h3 class="form-signin-heading">{% trans 'Password reset successful' %}</h3>
    </div>
    <div class="panel-body">
      <h4 class="text-success">{% trans "Your password has been set.  You may go ahead and log in now." %}</h4>
      <p class="text-center"><a href="{{ login_url }}" class="btn btn-primary">{% trans 'Log in' %}</a></p>
    </div>
  </div>

</div> <!-- /container -->
{% endblock %}